action_pair = {
    "HpcIaasGetChargeRecords": "get_charge_records",
    "HpcQueuestrategyAddEhpcQueueStrategy": "add_ehpc_queue_strategy",
    "HpcQueuestrategyDelEhpcQueueStrategy": "del_ehpc_queue_strategy",
    "HpcQueuestrategyModifyEhpcQueueStrategy": "modify_ehpc_queue_strategy",
    "HpcQueuestrategyEnableEhpcQueueStrategy": "enable_ehpc_queue_strategy",
    "HpcQueuestrategyGetEhpcQueueStrategyList": "get_ehpc_queue_strategy_list",
    "HpcQueuestrategyGetEhpcQueueStrategyLogList": "get_ehpc_queue_strategy_log_list",
    "HpcJobListJobs": "list_jobs",
    "HpcJobGetJobMonitor": "get_job_monitor",
    "HpcJobUpdateJobStatus": "update_job_status",
    "HpcJobPushJobMetrics": "push_job_metrics",
    "HpcJobGetJobDetail": "get_job_detail",
    "HpcJobCreateJobFile": "create_job_file",
    "HpcJobSubmitJob": "submit_job",
    "HpcSimulationSubmitSimulationJob": "submit_simulation_job",
    "HpcSimulationListSimulationJobs": "list_simulation_jobs",
    "HpcSimulationStopSimulationJobs": "stop_simulation_jobs",
    "HpcSimulationDeleteSimulationJobs": "delete_simulation_jobs",
    "HpcSimulationGetSimulationJobDetail": "get_simulation_job_detail",
    "HpcJobUpdateEhpcJobStatus": "update_ehpc_job_status",
    "HpcJobRecoverJobStatus": "recover_job_status",
    "HpcJobStopJobs": "stop_jobs",
    "HpcJobResumeJobs": "resume_jobs",
    "HpcJobDeleteJobs": "delete_jobs",
    "HpcJobtemplateJobCreateTemplate": "job_create_template",
    "HpcJobtemplateJobListTemplates": "job_list_templates",
    "HpcJobtemplateJobTemplateDetail": "job_template_detail",
    "HpcJobtemplateJobTemplateDelete": "job_template_delete",
    "HpcJobtemplateJobTemplateUpdate": "job_template_update",
    "HpcFiletemplateFileCreateTemplate": "file_create_template",
    "HpcFiletemplateFileListTemplates": "file_list_templates",
    "HpcFiletemplateFileTemplateDetail": "file_template_detail",
    "HpcFiletemplateFileTemplateDelete": "file_template_delete",
    "HpcFiletemplateFileTemplateUpdate": "file_template_update",
    "HpcOperationListOperation": "list_operation",
    "HpcOperationSimulationOperation": "simulation_operation",
    "HpcOperationHelloWorld": "hello_world",
    "HpcCliRunCmd": "run_cmd",
    "HpcUserListUsers": "list_users",
    "HpcUserDescribeHpcLoginAccountUser": "describe_hpc_login_account_user",
    "HpcUserAddUser": "add_user",
    "HpcUserModifyUser": "modify_user",
    "HpcUserDeleteUser": "delete_user",
    "HpcSubuserListSubusers": "list_subusers",
    "HpcPermissionEnableHpc": "enable_hpc",
    "HpcPermissionDisableHpc": "disable_hpc",
    "HpcPermissionGetHpcStatus": "get_hpc_status",
    "HpcBillingGetProductBillingModel": "get_product_billing_model",
    "HpcBillingGetCost": "get_cost",
    "HpcBillingGetMeter": "get_meter",
    "HpcBillingRemoteappNotify": "remoteapp_notify",
    "HpcBillingNotify": "notify",
    "HpcBillingListRemoteappLog": "list_remoteapp_log",
    "HpcQueueBindPrivateQueue": "bind_private_queue",
    "HpcQueueAddQueueType": "add_queue_type",
    "HpcQueueDelQueueTypes": "del_queue_types",
    "HpcQueueGetQueueTypeList": "get_queue_type_list",
    "HpcQueueGetQueueTypes": "get_queue_types",
    "HpcQueueAddPhyQueue": "add_phy_queue",
    "HpcQueueDelPhyQueues": "del_phy_queues",
    "HpcQueueGetPhyQueues": "get_phy_queues",
    "HpcQueueAddEhpcQueue": "add_ehpc_queue",
    "HpcQueueModifyEhpcQueue": "modify_ehpc_queue",
    "HpcQueueAddEhpcQueueNodes": "add_ehpc_queue_nodes",
    "HpcQueueRemoveEhpcQueueNodes": "remove_ehpc_queue_nodes",
    "HpcQueueDelEhpcQueues": "del_ehpc_queues",
    "HpcQueueGetEhpcQueueList": "get_ehpc_queue_list",
    "HpcQueueGetCurrentQueue": "get_current_queue",
    "HpcQueueUnbindPrivateQueue": "unbind_private_queue",
    "HpcQueueIsAvailableQueue": "is_available_queue",
    "HpcQueueUpdateQueueName": "update_queue_name",
    "HpcQueueDescribeQueue": "describe_queue",
    "HpcQueueGetQueueNodes": "get_queue_nodes",
    "HpcRentGetClusterPrivateResourceInfo": "get_cluster_private_resource_info",
    "HpcRentGetClusterShareResourceInfo": "get_cluster_share_resource_info",
    "HpcRentGetClusterBillInfo": "get_cluster_bill_info",
    "HpcRentGetRemoteappBillInfo": "get_remoteapp_bill_info",
    "HpcRentGetHpcFreeInfo": "get_hpc_free_info",
    "HpcClusterListCluster": "list_cluster",
    "HpcClusterGetHpcClusterDetail": "get_hpc_cluster_detail",
    "HpcClusterCreateCluster": "create_cluster",
    "HpcClusterDeleteCluster": "delete_cluster",
    "HpcClusterModifyCluster": "modify_cluster",
    "HpcClusterResizeClusterFee": "resize_cluster_fee",
    "HpcClusterResizeCluster": "resize_cluster",
    "HpcClusterStartCluster": "start_cluster",
    "HpcClusterStopCluster": "stop_cluster",
    "HpcClusterResumeCluster": "resume_cluster",
    "HpcClusterGetClusterNodes": "get_cluster_nodes",
    "HpcClusterAddClusterNodesFee": "add_cluster_nodes_fee",
    "HpcClusterAddClusterNodes": "add_cluster_nodes",
    "HpcClusterDeleteClusterNodes": "delete_cluster_nodes",
    "HpcClusterRestartClusterNodes": "restart_cluster_nodes",
    "HpcClusterGetNasInfo": "get_nas_info",
    "HpcClusterAssociateLoginNodeEip": "associate_login_node_eip",
    "HpcClusterDissociateLoginNodeEip": "dissociate_login_node_eip",
    "HpcClusterUpgradeCluster": "upgrade_cluster",
    "HpcClusterGetClusterConf": "get_cluster_conf",
    "HpcSoftwareGetGraphics": "get_graphics",
    "HpcSoftwareApplySoftware": "apply_software",
    "HpcSoftwareGetApply": "get_apply",
    "HpcSoftwareUpdateApply": "update_apply",
    "HpcSoftwareGetList": "get_list",
    "HpcSoftwareStartSoftware": "start_software",
    "HpcSoftwareStopSoftware": "stop_software",
    "HpcSoftwareModifySoftware": "modify_software",
    "HpcSoftwareDeleteSoftware": "delete_software",
    "HpcSoftwareAddSoftware": "add_software",
    "HpcSoftwareDeleteClass": "delete_class",
    "HpcSoftwareGetRemoteappLink": "get_remoteapp_link",
    "HpcSoftwareListClass": "list_class",
    "HpcSoftwareMark": "mark",
    "HpcSoftwareGetClusterSoftwareList": "get_cluster_software_list",
    "HpcSoftwareInstallClusterSoftwares": "install_cluster_softwares",
    "HpcSoftwareUninstallClusterSoftwares": "uninstall_cluster_softwares",
    "HpcProjectListProject": "list_project",
    "HpcProjectCreateProject": "create_project",
    "HpcProjectDestroyProject": "destroy_project",
    "HpcProjectModifyProject": "modify_project",
    "HpcProjectListMember": "list_member",
    "HpcProjectAddMember": "add_member",
    "HpcProjectDelMember": "del_member",
    "HpcProjectModifyMember": "modify_member",
    "HpcProjectListResource": "list_resource",
    "HpcProjectAddResource": "add_resource",
    "HpcProjectDelResource": "del_resource",
    "HpcProjectModifyResource": "modify_resource",
    "HpcProjectInitConfiguration": "init_configuration",
    "HpcProjectListProjectRole": "list_project_role",
    "HpcProjectCreateProjectRole": "create_project_role",
    "HpcProjectDestroyProjectRole": "destroy_project_role",
    "HpcProjectModifyProjectRole": "modify_project_role",
    "HpcProjectListProjectRuleGroup": "list_project_rule_group",
    "HpcProjectCreateProjectRuleGroup": "create_project_rule_group",
    "HpcProjectDestroyProjectRuleGroup": "destroy_project_rule_group",
    "HpcProjectModifyProjectRuleGroup": "modify_project_rule_group",
    "HpcProjectAddProjectRuleGroup": "add_project_rule_group",
    "HpcProjectDelProjectRuleGroup": "del_project_rule_group",
    "HpcProjectListProjectRule": "list_project_rule",
    "HpcProjectCreateProjectRule": "create_project_rule",
    "HpcProjectDestroyProjectRule": "destroy_project_rule",
    "HpcProjectModifyProjectRule": "modify_project_rule",
    "HpcProjectAddProjectRule": "add_project_rule",
    "HpcProjectDelProjectRule": "del_project_rule",
    "HpcEpmrListEhpcSubuserStor": "list_ehpc_subuser_stor",
    "HpcEpmrEnableEhpcSubuserStor": "enable_ehpc_subuser_stor",
    "HpcEpmrGetEhpcSubuserStorEnableStatus": "get_ehpc_subuser_stor_enable_status"
}

enable_action_pair = {
    "HpcIaasGetChargeRecords": "get_charge_records",
    "HpcQueuestrategyAddEhpcQueueStrategy": "add_ehpc_queue_strategy",
    "HpcQueuestrategyDelEhpcQueueStrategy": "del_ehpc_queue_strategy",
    "HpcQueuestrategyModifyEhpcQueueStrategy": "modify_ehpc_queue_strategy",
    "HpcQueuestrategyEnableEhpcQueueStrategy": "enable_ehpc_queue_strategy",
    "HpcQueuestrategyGetEhpcQueueStrategyList": "get_ehpc_queue_strategy_list",
    "HpcQueuestrategyGetEhpcQueueStrategyLogList": "get_ehpc_queue_strategy_log_list",
    "HpcJobListJobs": "list_jobs",
    "HpcJobGetJobMonitor": "get_job_monitor",
    "HpcJobUpdateJobStatus": "update_job_status",
    "HpcJobPushJobMetrics": "push_job_metrics",
    "HpcJobGetJobDetail": "get_job_detail",
    "HpcJobCreateJobFile": "create_job_file",
    "HpcJobSubmitJob": "submit_job",
    "HpcSimulationSubmitSimulationJob": "submit_simulation_job",
    "HpcSimulationListSimulationJobs": "list_simulation_jobs",
    "HpcSimulationStopSimulationJobs": "stop_simulation_jobs",
    "HpcSimulationDeleteSimulationJobs": "delete_simulation_jobs",
    "HpcSimulationGetSimulationJobDetail": "get_simulation_job_detail",
    "HpcJobUpdateEhpcJobStatus": "update_ehpc_job_status",
    "HpcJobRecoverJobStatus": "recover_job_status",
    "HpcJobStopJobs": "stop_jobs",
    "HpcJobResumeJobs": "resume_jobs",
    "HpcJobDeleteJobs": "delete_jobs",
    "HpcJobtemplateJobCreateTemplate": "job_create_template",
    "HpcJobtemplateJobListTemplates": "job_list_templates",
    "HpcJobtemplateJobTemplateDetail": "job_template_detail",
    "HpcJobtemplateJobTemplateDelete": "job_template_delete",
    "HpcJobtemplateJobTemplateUpdate": "job_template_update",
    "HpcFiletemplateFileCreateTemplate": "file_create_template",
    "HpcFiletemplateFileListTemplates": "file_list_templates",
    "HpcFiletemplateFileTemplateDetail": "file_template_detail",
    "HpcFiletemplateFileTemplateDelete": "file_template_delete",
    "HpcFiletemplateFileTemplateUpdate": "file_template_update",
    "HpcOperationListOperation": "list_operation",
    "HpcOperationSimulationOperation": "simulation_operation",
    "HpcOperationHelloWorld": "hello_world",
    "HpcCliRunCmd": "run_cmd",
    "HpcUserListUsers": "list_users",
    "HpcUserDescribeHpcLoginAccountUser": "describe_hpc_login_account_user",
    "HpcUserAddUser": "add_user",
    "HpcUserModifyUser": "modify_user",
    "HpcUserDeleteUser": "delete_user",
    "HpcSubuserListSubusers": "list_subusers",
    "HpcPermissionEnableHpc": "enable_hpc",
    "HpcPermissionDisableHpc": "disable_hpc",
    "HpcPermissionGetHpcStatus": "get_hpc_status",
    "HpcBillingGetProductBillingModel": "get_product_billing_model",
    "HpcBillingGetCost": "get_cost",
    "HpcBillingGetMeter": "get_meter",
    "HpcBillingRemoteappNotify": "remoteapp_notify",
    "HpcBillingNotify": "notify",
    "HpcBillingListRemoteappLog": "list_remoteapp_log",
    "HpcQueueBindPrivateQueue": "bind_private_queue",
    "HpcQueueAddQueueType": "add_queue_type",
    "HpcQueueDelQueueTypes": "del_queue_types",
    "HpcQueueGetQueueTypeList": "get_queue_type_list",
    "HpcQueueGetQueueTypes": "get_queue_types",
    "HpcQueueAddPhyQueue": "add_phy_queue",
    "HpcQueueDelPhyQueues": "del_phy_queues",
    "HpcQueueGetPhyQueues": "get_phy_queues",
    "HpcQueueAddEhpcQueue": "add_ehpc_queue",
    "HpcQueueModifyEhpcQueue": "modify_ehpc_queue",
    "HpcQueueAddEhpcQueueNodes": "add_ehpc_queue_nodes",
    "HpcQueueRemoveEhpcQueueNodes": "remove_ehpc_queue_nodes",
    "HpcQueueDelEhpcQueues": "del_ehpc_queues",
    "HpcQueueGetEhpcQueueList": "get_ehpc_queue_list",
    "HpcQueueGetCurrentQueue": "get_current_queue",
    "HpcQueueUnbindPrivateQueue": "unbind_private_queue",
    "HpcQueueIsAvailableQueue": "is_available_queue",
    "HpcQueueUpdateQueueName": "update_queue_name",
    "HpcQueueDescribeQueue": "describe_queue",
    "HpcQueueGetQueueNodes": "get_queue_nodes",
    "HpcRentGetClusterPrivateResourceInfo": "get_cluster_private_resource_info",
    "HpcRentGetClusterShareResourceInfo": "get_cluster_share_resource_info",
    "HpcRentGetClusterBillInfo": "get_cluster_bill_info",
    "HpcRentGetRemoteappBillInfo": "get_remoteapp_bill_info",
    "HpcRentGetHpcFreeInfo": "get_hpc_free_info",
    "HpcClusterListCluster": "list_cluster",
    "HpcClusterGetHpcClusterDetail": "get_hpc_cluster_detail",
    "HpcClusterCreateCluster": "create_cluster",
    "HpcClusterDeleteCluster": "delete_cluster",
    "HpcClusterModifyCluster": "modify_cluster",
    "HpcClusterResizeClusterFee": "resize_cluster_fee",
    "HpcClusterResizeCluster": "resize_cluster",
    "HpcClusterStartCluster": "start_cluster",
    "HpcClusterStopCluster": "stop_cluster",
    "HpcClusterResumeCluster": "resume_cluster",
    "HpcClusterGetClusterNodes": "get_cluster_nodes",
    "HpcClusterAddClusterNodesFee": "add_cluster_nodes_fee",
    "HpcClusterAddClusterNodes": "add_cluster_nodes",
    "HpcClusterDeleteClusterNodes": "delete_cluster_nodes",
    "HpcClusterRestartClusterNodes": "restart_cluster_nodes",
    "HpcClusterGetNasInfo": "get_nas_info",
    "HpcClusterAssociateLoginNodeEip": "associate_login_node_eip",
    "HpcClusterDissociateLoginNodeEip": "dissociate_login_node_eip",
    "HpcClusterUpgradeCluster": "upgrade_cluster",
    "HpcClusterGetClusterConf": "get_cluster_conf",
    "HpcSoftwareGetGraphics": "get_graphics",
    "HpcSoftwareApplySoftware": "apply_software",
    "HpcSoftwareGetApply": "get_apply",
    "HpcSoftwareUpdateApply": "update_apply",
    "HpcSoftwareGetList": "get_list",
    "HpcSoftwareStartSoftware": "start_software",
    "HpcSoftwareStopSoftware": "stop_software",
    "HpcSoftwareModifySoftware": "modify_software",
    "HpcSoftwareDeleteSoftware": "delete_software",
    "HpcSoftwareAddSoftware": "add_software",
    "HpcSoftwareDeleteClass": "delete_class",
    "HpcSoftwareGetRemoteappLink": "get_remoteapp_link",
    "HpcSoftwareListClass": "list_class",
    "HpcSoftwareMark": "mark",
    "HpcSoftwareGetClusterSoftwareList": "get_cluster_software_list",
    "HpcSoftwareInstallClusterSoftwares": "install_cluster_softwares",
    "HpcSoftwareUninstallClusterSoftwares": "uninstall_cluster_softwares",
    "HpcProjectListProject": "list_project",
    "HpcProjectCreateProject": "create_project",
    "HpcProjectDestroyProject": "destroy_project",
    "HpcProjectModifyProject": "modify_project",
    "HpcProjectListMember": "list_member",
    "HpcProjectAddMember": "add_member",
    "HpcProjectDelMember": "del_member",
    "HpcProjectModifyMember": "modify_member",
    "HpcProjectListResource": "list_resource",
    "HpcProjectAddResource": "add_resource",
    "HpcProjectDelResource": "del_resource",
    "HpcProjectModifyResource": "modify_resource",
    "HpcProjectInitConfiguration": "init_configuration",
    "HpcProjectListProjectRole": "list_project_role",
    "HpcProjectCreateProjectRole": "create_project_role",
    "HpcProjectDestroyProjectRole": "destroy_project_role",
    "HpcProjectModifyProjectRole": "modify_project_role",
    "HpcProjectListProjectRuleGroup": "list_project_rule_group",
    "HpcProjectCreateProjectRuleGroup": "create_project_rule_group",
    "HpcProjectDestroyProjectRuleGroup": "destroy_project_rule_group",
    "HpcProjectModifyProjectRuleGroup": "modify_project_rule_group",
    "HpcProjectAddProjectRuleGroup": "add_project_rule_group",
    "HpcProjectDelProjectRuleGroup": "del_project_rule_group",
    "HpcProjectListProjectRule": "list_project_rule",
    "HpcProjectCreateProjectRule": "create_project_rule",
    "HpcProjectDestroyProjectRule": "destroy_project_rule",
    "HpcProjectModifyProjectRule": "modify_project_rule",
    "HpcProjectAddProjectRule": "add_project_rule",
    "HpcProjectDelProjectRule": "del_project_rule",
    "HpcEpmrListEhpcSubuserStor": "list_ehpc_subuser_stor",
    "HpcEpmrEnableEhpcSubuserStor": "enable_ehpc_subuser_stor",
    "HpcEpmrGetEhpcSubuserStorEnableStatus": "get_ehpc_subuser_stor_enable_status"
}